﻿using System;
using System.Collections.Generic;
using System.Text;

namespace DocIO_Test
{
    /// <summary>
    /// Conversion helper from Unix time to Datetime and Datetime to Unix time
    /// </summary>
    public static class UnixDateTimeExtension
    {
        /// <summary>
        /// epoch start datetime
        /// </summary>
        private static readonly DateTime epoch = new DateTime(1970, 1, 1, 0, 0, 0, DateTimeKind.Utc);

        /// <summary>
        /// Converts Unix time to DateTime
        /// </summary>
        /// <param name="unixTime"></param>
        /// <returns></returns>
        public static DateTime FromUnixTime(this long unixTime)
        {
            return epoch.AddSeconds(unixTime);
        }

        /// <summary>
        /// Converts DateTime Now to Unix Time
        /// </summary>
        /// <returns></returns>
        public static long GetUnixTimeNow()
        {
            return Convert.ToInt64((DateTime.UtcNow - epoch).TotalSeconds);
        }

        /// <summary>
        /// Converts Datetime to Unix time
        /// </summary>
        /// <param name="date"></param>
        /// <returns></returns>
        public static long ToUnixTime(this DateTime date)
        {
            return Convert.ToInt64((date - epoch).TotalSeconds);
        }
    }
}
